@@ -393,8 +393,12 @@ pulse_ext_stream_update (PulseExtStream                   *ext,
     _mate_mixer_stream_control_set_flags (MATE_MIXER_STREAM_CONTROL (ext), flags);
 
     /* Also set initially, but may change at any time */
-    _mate_mixer_stream_control_set_stream (MATE_MIXER_STREAM_CONTROL (ext),
-                                           MATE_MIXER_STREAM (parent));
+    if (parent != NULL)
+        _mate_mixer_stream_control_set_stream (MATE_MIXER_STREAM_CONTROL (ext),
+                                               MATE_MIXER_STREAM (parent));
+    else
+        _mate_mixer_stream_control_set_stream (MATE_MIXER_STREAM_CONTROL (ext),
+                                               NULL);
 
     g_object_thaw_notify (G_OBJECT (ext));
 }
@@ -599,7 +603,7 @@ pulse_ext_stream_get_max_volume (MateMixerStreamControl *mmsc)
 {
     g_return_val_if_fail (PULSE_IS_EXT_STREAM (mmsc), (guint) PA_VOLUME_MUTED);
 
-    return (guint) PA_VOLUME_UI_MAX;
+    return (guint) PA_VOLUME_NORM;
 }
 
 static guint
